==> RsCMPX_Base-4.0.180-py3-none-any.whl: RsCMPX_Base/Implementations/Route/Gprf/Measurement/Spath.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpathCls:
	"""Spath commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spath", core, parent)

	def get_count(self) -> int:
		"""SCPI: ROUTe:GPRF:MEASurement<Instance>:SPATh:COUNt \n
		Snippet: value: int = driver.route.gprf.measurement.spath.get_count() \n
		No command help available \n
			:return: signal_path_count: No help available
		"""
		response = self._core.io.query_str('ROUTe:GPRF:MEASurement<Instance>:SPATh:COUNt?')
		return Conversions.str_to_int(response)

	def get_value(self) -> List[str]:
		"""SCPI: ROUTe:GPRF:MEASurement<Instance>:SPATh \n
		Snippet: value: List[str] = driver.route.gprf.measurement.spath.get_value() \n
		No command help available \n
			:return: signal_path: No help available
		"""
		response = self._core.io.query_str('ROUTe:GPRF:MEASurement<Instance>:SPATh?')
		return Conversions.str_to_str_list(response)

	def set_value(self, signal_path: List[str]) -> None:
		"""SCPI: ROUTe:GPRF:MEASurement<Instance>:SPATh \n
		Snippet: driver.route.gprf.measurement.spath.set_value(signal_path = ['1', '2', '3']) \n
		No command help available \n
			:param signal_path: No help available
		"""
		param = Conversions.list_to_csv_quoted_str(signal_path)
		self._core.io.write(f'ROUTe:GPRF:MEASurement<Instance>:SPATh {param}')

==> RsCMPX_Base-5.0.60-py3-none-any.whl: RsCMPX_Base/Implementations/Route/Gprf/Measurement/Spath.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpathCls:
	"""Spath commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spath", core, parent)

	def get_count(self) -> int:
		"""SCPI: ROUTe:GPRF:MEASurement<Instance>:SPATh:COUNt \n
		Snippet: value: int = driver.route.gprf.measurement.spath.get_count() \n
		No command help available \n
			:return: signal_path_count: No help available
		"""
		response = self._core.io.query_str('ROUTe:GPRF:MEASurement<Instance>:SPATh:COUNt?')
		return Conversions.str_to_int(response)

	def get_value(self) -> List[str]:
		"""SCPI: ROUTe:GPRF:MEASurement<Instance>:SPATh \n
		Snippet: value: List[str] = driver.route.gprf.measurement.spath.get_value() \n
		No command help available \n
			:return: signal_path: No help available
		"""
		response = self._core.io.query_str('ROUTe:GPRF:MEASurement<Instance>:SPATh?')
		return Conversions.str_to_str_list(response)

	def set_value(self, signal_path: List[str]) -> None:
		"""SCPI: ROUTe:GPRF:MEASurement<Instance>:SPATh \n
		Snippet: driver.route.gprf.measurement.spath.set_value(signal_path = ['abc1', 'abc2', 'abc3']) \n
		No command help available \n
			:param signal_path: No help available
		"""
		param = Conversions.list_to_csv_quoted_str(signal_path)
		self._core.io.write(f'ROUTe:GPRF:MEASurement<Instance>:SPATh {param}')
